# Plato

[![PyPI](https://img.shields.io/pypi/v/plato-draw.svg?style=flat)](https://pypi.org/project/plato-draw/)
[![ReadTheDocs](https://img.shields.io/readthedocs/plato-draw.svg?style=flat)](https://plato-draw.readthedocs.io/en/latest/)
[![CircleCI](https://img.shields.io/circleci/project/github/glotzerlab/plato/master.svg?style=flat)](https://circleci.com/gh/glotzerlab/plato)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/glotzerlab/plato/master?filepath=examples)

Plato is designed for efficient visualization of particle data.
Think of it sort of like matplotlib, but being less focused on 2D plotting.

For quick examples of the types of visualizations plato can generate,
see the
[gallery](https://github.com/glotzerlab/plato-gallery).

## Documentation

See the full documentation at https://plato-draw.readthedocs.io.
Documentation can also be built using sphinx:

```
cd doc
make html
```
